import com.jinsight.jetchart.*;
import java.io.*;
import java.awt.*;
import javax.swing.*;
import java.awt.image.*;

/**
 * This example demonstrates how  to  generate  offscreen  chart images  using the ChartEncoder.class.
 * This class is found in the Encoders.jar and sEncoders.jar files, which are the to be used with 
 * AWT(heavyweight) and Swing(lightweight) components, respectively. One of these files has to be 
 * be included in  the   classpath. Both files can be found in the JetChart/lib directory.
 * The ChartEncoder class internally creates a Frame or JFrame object to lay out an AWT or Swing
 * instance of a Graph or PieGraph class. Use  sChartEncoder.jar with sGraphChart.jar,
 * sPieChart.jar and sScatterChart.jar, and ChartEncoder.jar with GraphChart.jar, PieChart.jar and
 * ScatterChart.jar.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main {

    Graph graph;

    public Main() {
	
        FileOutputStream jpegOut=null,pngOut=null,gifOut=null;

	try {
	    
            // Creates the output files.
	    jpegOut=new FileOutputStream("chart.jpg");
	    pngOut=new FileOutputStream("chart.png");
	    gifOut=new FileOutputStream("chart.gif");

	    // Creates a simple chart.
	    createChart();

            // The following method has to be set to true, if the Graph object is used
            // to generated offscreen images.
            graph.setOffScreenGraphEnabled(true);

            graph.setSize(500,400);

            // Creates the chart encoder class.
            ChartEncoder ce=new ChartEncoder(graph);
	 
            // Generates the jpeg file, setting the image quality to 85%.
            System.out.println("Generating chart.jpg...");
	    ce.jpegEncode(jpegOut,85);
	  
	    // Generates the png file. The compression level is set to 9(may vary from 1 to 9).
            System.out.println("Generating chart.png...");
	    ce.pngEncode(pngOut,9);

	    // Generates the gif file.
            System.out.println("Generating chart.gif...");
            ce.gifEncode(gifOut);
	    	                  
	    jpegOut.flush();
	    pngOut.flush();
	    gifOut.flush();
	    
            // The ChartEncoder class internally creates an invisible Frame   object,
            // and the AWT thread is activated. For this reason, even after the main
            // thread has finished, the application hangs, because the JVM does not
            // exit if  there  is any  active thread running. So, the only way to 
            // terminate  the  application is by making a explicit call to System.exit(0).
	    System.exit(0);
	    
	}
	catch (Exception e) {
	    e.printStackTrace();
	}
	finally {
	    
	    try {
		
                // Closes the output streams.
		if (jpegOut!=null)
		    jpegOut.close();
		if (pngOut!=null)
		    pngOut.close();
		if (gifOut!=null)
		    gifOut.close();

	    }
	    catch (IOException e) {
		e.printStackTrace();
	    }
	}
    }
    
    private void createChart() {

	graph=new Graph();
        graph.setTitle(new String[]{"The JetChart Library","Offscreen chart image generation"});
        graph.setTitleForeground(Color.blue);
	graph.setBackground(Color.decode("#ffffcc"));
        graph.set3DEnabled(true);
        graph.getGraphSet(0).getGrid().setEnabled(true);

	// Creates a bar series.
	BarSerie bs=new BarSerie();
        bs.setWidth(15);
	bs.setValues(new double[]{200,300,100,400,500});
	bs.setColor(Color.green);
	bs.setTitle("Bar series");

	graph.addSerie(bs);

    }

    public static void main(String[] args) {
	new Main();
    }

}



