import com.jinsight.jetchart.*;
import java.io.*;
import java.awt.*;
import javax.swing.*;
import java.awt.image.*;

/**
 * This example demonstrates how  to  generate  offscreen chart  images using
 * a JPEG,PNG and GIF encoders,  rather  than  using the methods  of JetChart
 * implemented for this specific purpose, as demonstrated by the  application
 * found in the 'example1' subdirectory.  The   encoders  are  jarred  in the
 * Encoders.jar or   sEncoders.jar  file.  The  first one is  to be used with 
 * the heavyweight versions of the classes Graph,PieGraph and ScatterGraph,and
 * the second is to be used with the Swing versions of these classes. 
 * The heavyweight versions of Graph, PieGraph and ScatterGraph are jarred in
 * the GraphChart.jar, PieChart.jar and ScatterChart.jar files,  respectively,
 * whereas the Swing versions are jarred in the sGraphChart.jar, sPieChart.jar
 * and sScatterChart.jar files.
 * Use Encoders.jar with GraphChart.jar, PieChart.jar and ScatterChart.jar, and
 * sEncoders.jar with sGraphChart.jar, sPieChart.jar and sScatterChart.jar.
 *
 * The image encoders found in Encoders.jar and sEncoders.jar  are: 
 * JpegEncoder.class, PngEncoder.class and GIFEncoder.class.
 * Encoders.jar and sEncoders.jar can be  found in the JetChart/lib directory.
 *	
 * This application is using the Swing version of JetChart.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main {

    Graph graph;

    public Main() {
	
	FileOutputStream jpegOut=null,pngOut=null,gifOut=null;
	
	try {
	    
	    // Creates the output files.
	    jpegOut=new FileOutputStream("chart.jpg");
	    pngOut=new FileOutputStream("chart.png");
	    gifOut=new FileOutputStream("chart.gif");
	    
	    // Creates a simple chart.
	    createChart();
	 
	    // An invisible JFrame object is required to lay out the Graph object and
            // to create a valid Image object. The dimensions of the Graph and Image
            // objects are set in reference to the JFrame size.
            JFrame f=new JFrame();
	    f.getContentPane().add("Center",graph);
	    f.setSize(500,400);

            // A call to this method creates the native component of the JFrame object.
	    f.addNotify();
	    f.validate();
	    
	    // Creates an Image object with the same dimensions of the chart context.
	    // Although the frame size has been set to (500,400), there will be a small
	    // difference in the image width and height, because the Graph object does
	    // not stretch to fit the entire Frame area.
	    Image image=f.createImage(graph.getSize().width,graph.getSize().height);
	    
	    // Gets the image graphical context.
	    Graphics g=image.getGraphics();
	    
	    // Paints chart on the Image graphical context. This is a Swing demo, so
	    // we must invoke the method 'paintComponent(Graphics g)', instead of 
	    // 'paint(Graphics g)'.
	    graph.paintComponent(g);
	    
	    // Disposes of the JFrame object.
	    f.dispose();
	    
	    // Jpeg encodes the image sending encoded bytes to the file. Sets
	    // the quality to 85%. The better the quality the larger the  file 
	    // size is.
	    JpegEncoder jpeg = new JpegEncoder(image,85,jpegOut);

            System.out.println("Generating chart.jpg...");
	    jpeg.encode();
	  
	    // Png encodes the image sending encoded bytes to the file. The
	    // compression level is set to 9(may vary from 1 to 9).
	    PngEncoder png=new PngEncoder(image,9,pngOut);
            
            System.out.println("Generating chart.png...");
	    png.encode();
	    
	    // Gif encodes the image sending encoded bytes to the file.
	    GifEncoder gif=new GifEncoder(image,gifOut);

            System.out.println("Generating chart.gif...");
	    gif.encode();
	    	                  
            // Disposes of the Image object graphical context.
            g.dispose();

	    jpegOut.flush();
	    pngOut.flush();
	    gifOut.flush();
	    
            // After  creating  the  native  component  of the  Frame object with the  
            // method  addNotify(), the  AWT  thread  is  activated,  and there is no
            // public methods  avaliable  to  deactivate  it. For  this reason,  even 
            // after the main thread has finished, the application hangs, because the
            // JVM  does  not  exit if  there  is any  active thread running. So, the
            // only  way to  terminate  the  application is by making a explicit call
            // to System.exit(0).
	    System.exit(0);
	    
	}
	catch (Exception e) {
	    e.printStackTrace();
	}
	finally {
	    
	    try {
		
                // Closes the output streams.
		if (jpegOut!=null)
		    jpegOut.close();
		if (pngOut!=null)
		    pngOut.close();
		if (gifOut!=null)
		    gifOut.close();

	    }
	    catch (IOException e) {
		e.printStackTrace();
	    }
	}
    }
    
    private void createChart() {

	graph=new Graph();
        graph.setTitle(new String[]{"The JetChart Library","Offscreen chart image generation"});
        graph.setTitleForeground(Color.blue);
	graph.setBackground(Color.decode("#ffffcc"));
        graph.set3DEnabled(true);
        graph.getGraphSet(0).getGrid().setEnabled(true);

	// Creates a bar series.
	BarSerie bs=new BarSerie();
        bs.setWidth(15);
	bs.setValues(new double[]{200,300,100,400,500});
	bs.setColor(Color.green);
	bs.setTitle("Bar series");

	graph.addSerie(bs);

    }

    public static void main(String[] args) {
	new Main();
    }

}



