import com.jinsight.jetchart.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * This demo gives an example of scale range adjustment.
 *
 * @author Andre de Lima Soares
 */

public class Main extends JFrame implements ItemListener,AdjustmentListener {
    
    Graph graph;
    JPanel p,p2;
    JScrollBar minRangeValue,rangeIncrement;
    JCheckBox cb,cb2;
    JLabel minRange,increment;

    public Main()  {

	setTitle("The JetChart Library - Scale Adjustment Demo");

	createPanels();

	graph=new Graph();

	graph.setVerticalLabelsEnabled(true);

	setChartProperties();

	AreaSerie as=new AreaSerie(new double[]{910,905,903,915,930,928,917,901},"Area Series");
	as.setColor(Color.red);
	
	graph.addSerie(as);

	Container ct=getContentPane();

	ct.add("North",p);
	ct.add("Center",graph);
	ct.add("South",p2);
	
	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });
	
	setSize(600,500);
	setVisible(true);
    }

    private void createPanels() {
	p=new JPanel();

	cb=new JCheckBox("Disable auto-increment");
	cb.setFont(new Font("SansSerif",Font.PLAIN,10));
	
	cb.addItemListener(this);
	p.add(cb);

	JLabel l=new JLabel("Min value:");
	l.setFont(new Font("SansSerif",Font.PLAIN,10));
	p.add(l);
	// Scrollbar for range adjustment
	minRangeValue=new JScrollBar(Scrollbar.HORIZONTAL,900,1,0,901);
	minRangeValue.setPreferredSize(new Dimension(100,minRangeValue.getPreferredSize().height));

	minRangeValue.addAdjustmentListener(this);
	p.add(minRangeValue);

	JLabel l1=new JLabel("Range increment:");
	l1.setFont(new Font("SansSerif",Font.PLAIN,10));
	p.add(l1);


	// Scrollbar for range increment
	rangeIncrement=new JScrollBar(JScrollBar.HORIZONTAL,2,1,0,101);
	rangeIncrement.setPreferredSize(new Dimension(100,rangeIncrement.getPreferredSize().height));

	rangeIncrement.addAdjustmentListener(this);
	p.add(rangeIncrement);

	p2=new JPanel();
	p2.setLayout(new FlowLayout(FlowLayout.LEFT));

	cb2=new JCheckBox("Horizontal chart");
	cb2.setFont(new Font("SansSerif",Font.PLAIN,10));
	cb2.addItemListener(this);
	p2.add(cb2);

	JLabel l3=new JLabel("Min range value:");
	l3.setFont(new Font("SansSerif",Font.PLAIN,10));
	minRange=new JLabel("900");
	minRange.setFont(new Font("SansSerif",Font.PLAIN,10));

	JLabel l4=new JLabel("Range increment:");
	l4.setFont(new Font("SansSerif",Font.PLAIN,10));
	increment=new JLabel("2");
	increment.setFont(new Font("SansSerif",Font.PLAIN,10));
	
	p2.add(l3);
	p2.add(minRange);
	p2.add(l4);
	p2.add(increment);

    }

    private void setChartProperties() {
	graph.setStartDate("07012000");
	graph.setDateIncrement(Graph.MONTH_INCREMENT);
	graph.setTitle(new String[]{"The JetChart Library","Scale adjustment demo"});

	// Gets a reference to the scale of the primary GraphSet object. See JetChart
	// documentation about the GraphSet class for further details.
	Scale scale=graph.getGraphSet(0).getScale();

	// sets minimum range value
	scale.setMinValue(900);

	// sets range increment
	scale.setIncrement(2);
	
	// sets 3D effect
	graph.set3DEnabled(true);

	// sets serie start position
	graph.setLabelsAxisStartGap(0);
	
	// enables dragging
	graph.setDraggingEnabled(true);
	
	// enables tooltip 
	graph.getToolTip().setEnabled(true);

	// enables grid 
	graph.getGraphSet(0).getGrid().setEnabled(true);

	// enables grid crossed lines
	graph.getGraphSet(0).getGridCrossedLines().setEnabled(true);

	// sets background gradient colors
	graph.setGradientColors(Color.blue,Color.white);

    
    }
    
    public void itemStateChanged(ItemEvent evt) {
	if (evt.getSource()==cb) {
	    Scale scale=graph.getGraphSet(0).getScale();
	    scale.setAutoScaleEnabled(!cb.isSelected());
	}

	if (evt.getSource()==cb2) 
	    graph.setHorizontalGraphEnabled(cb2.isSelected());

	graph.repaint();
    }

    public void adjustmentValueChanged(AdjustmentEvent evt) {
	
	Scale scale=graph.getGraphSet(0).getScale();

	// sets new minimum range value
	if (evt.getSource()==minRangeValue) {

	    scale.setMinValue(minRangeValue.getValue());
	    minRange.setText(Integer.toString(minRangeValue.getValue()));
	    graph.repaint();
	}

	// sets new range increment
	if (evt.getSource()==rangeIncrement) {
	    
	    scale.setIncrement(rangeIncrement.getValue());
	    increment.setText(Integer.toString(rangeIncrement.getValue()));
	    graph.repaint();
	}
    }
    

    public static void main(String[] args) {
	new Main();
    }
}
