import com.jinsight.jetchart.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * A target line basically indicates  how a sequence of data points is
 * behaving in comparison with  a  target value. This demo  displays a 
 * bar series representing student grades of a specific discipline and
 * a target line positioned  at  the minimum required grade, making it
 * easier to distinguish which  students have successfully got through
 * the discipline or not. Tooltips are customized. If mouse cursor  is
 * moved over any bar, tooltips pop up, displaying customized messages.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 *
 */
public class Main extends JFrame implements ItemListener {

    Graph graph;
    BarSerie bs;
    JCheckBox cb1,cb2;

    public Main() {

        setTitle("The JetChart Library - Target Line Demo");

	// Creates a top panel, adding two checkboxes to it.
	createTopPanel();
	
	// Creates the graphic context and sets its properties.
	createGraph();

	// Enables the left title.
	LeftTitle lt=graph.getLeftTitle();
	lt.setText("Grade");
	lt.setFont(new Font("SansSerif",Font.BOLD,12));

	// Enables the bottom title.
	BottomTitle bt=graph.getBottomTitle();
	bt.setText("Students");
	bt.setFont(new Font("SansSerif",Font.BOLD,12));

	// Creates a bar series and sets its properties.
	createBarSeries();
	
	// Adds the bar series to the chart context.
	graph.addSerie(bs);

	// Creates a target line and sets its properties.
	TargetLine tl=new TargetLine(7.0);
	tl.setText("Minimum required grade: 7.0");

	/**
	 * The position of a target line text varies as specified below:
	 * ABOVE_LEFT
	 * ABOVE_CENTER => default position
	 * ABOVE_RIGHT
	 * BELOW_LEFT
	 * BELOW_CENTER
	 * BELOW_RIGHT
	 */
	tl.setTextPosition(TargetLine.BELOW_LEFT);
	tl.setColor(Color.blue.darker());

	// Gets a reference to the primary GraphSet object in order to add the 
	// target line, and sets scale and grid properties.
	GraphSet primaryGraphSet=graph.getGraphSet(0);

	// Adds the target line. An unlimited number of target lines can be added
	// to a GraphSet object. 
	primaryGraphSet.addTargetLine(tl);

	// Disables automatic scale and sets scale maximum value to 10.
	Scale scale=primaryGraphSet.getScale();
	scale.setAutoScaleEnabled(false);
	scale.setMaxValue(10);

	// Enables grid and sets its color to Color.lightGray.
	Grid grid=primaryGraphSet.getGrid();
	grid.setEnabled(true);
	grid.setColor(Color.lightGray);

	// Adds a window closing event handler.
	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });

	// Lays out graph on the Frame object.
        Container ct=getContentPane();
	ct.add("Center",graph);

	setSize(500,400);
	setVisible(true);

    }

    private void createGraph() {
	
	graph=new Graph();
	graph.set3DEnabled(true);
	graph.setBackground(new Color(204,255,255));
	graph.setVDepth(5);
	graph.getToolTip().setEnabled(true);

	graph.setTitle(new String[]{"Saint John's High School - Student Grades",
				    "Classroom B  - Discipline: Mathematics"});
	graph.setTitleFont(new Font("SansSerif",Font.BOLD,12));
	graph.setTitleForeground(Color.blue);
	
	graph.setLabels(new String[]{"Carlos","Afonso","Maria",
				     "Marcos","Ivan","Joana",
				     "Jose","Ronaldo","Raquel","Diana"});
	
	graph.setVerticalLabelsEnabled(true);
	graph.setLabelsFont(new Font("SansSerif",Font.PLAIN,12));

    }

    private void createBarSeries() {
	
	bs=new BarSerie();
	bs.setValues(new double[]{4.5,6.3,7.8,9.2,5.5,8.1,6.5,3.9,7.8,8.6});
	bs.setTitle("Student grades");
	bs.setLegendEnabled(false);
	bs.setBorderEnabled(false);
	bs.setColors(new Color[]{Color.red,Color.red,Color.green,Color.green,
				 Color.red,Color.green,Color.red,Color.red,
				 Color.green,Color.green});

	// Customizes tooltips contents. Move mouse cursor over any bar to see customized tooltip.
	String[] toolTipContents=new String[]{"Failed...","Failed...","Succeeded!","Succeeded!",
					      "Failed...","Succeeded!","Failed...","Failed...",
					      "Succeeded!","Succeeded!"};
	bs.setToolTipContent(toolTipContents);

    }

    private void createTopPanel() {

	JPanel topPanel=new JPanel(new FlowLayout(FlowLayout.LEFT));
	
	cb1=new JCheckBox("Horizontal");
	cb1.addItemListener(this);
	cb2=new JCheckBox("3D");
	cb2.setSelected(true);
	cb2.addItemListener(this);
	
	topPanel.add(cb1);
	topPanel.add(cb2);

        Container ct=getContentPane();
	ct.add("North",topPanel);
	
    }

    

    public void itemStateChanged(ItemEvent evt) {

	if (evt.getSource()==cb1)
	    graph.setHorizontalGraphEnabled(cb1.isSelected());
	else
	    graph.set3DEnabled(cb2.isSelected());

	graph.repaint();

    }

    public static void main(String[] args) {
	new Main();
    }

}
	
